@@ -8,8 +8,6 @@
 #define UTIL_MATH_MATHUTIL_H__
 
 #include <cmath>
-using std::abs;
-
 #include <algorithm>
 using std::min;
 using std::max;
@@ -108,8 +106,8 @@ class MathUtil {
     // Discriminants below kTolerance in absolute value are considered zero
     // because changing the final bit of one of the inputs can change the
     // sign of the discriminant.
-    const double kTolerance = epsilon * max(abs(2 * b * b), abs(4 * a * c));
-    return (abs(discriminant) <= kTolerance);
+    const double kTolerance = epsilon * max(std::abs(2 * b * b), std::abs(4 * a * c));
+    return (std::abs(discriminant) <= kTolerance);
   }
 
   // Returns in *r1 and *r2 the roots of a "normal" quadratic equation
@@ -290,8 +288,8 @@ class MathUtil {
   // --------------------------------------------------------------------
   template <class IntOut, class FloatIn>
   static IntOut Round(FloatIn x) {
-    static_assert(!MathLimits<FloatIn>::kIsInteger, "FloatIn_is_integer");
-    static_assert(MathLimits<IntOut>::kIsInteger, "IntOut_is_not_integer");
+    COMPILE_ASSERT(!MathLimits<FloatIn>::kIsInteger, FloatIn_is_integer);
+    COMPILE_ASSERT(MathLimits<IntOut>::kIsInteger, IntOut_is_not_integer);
 
     // We don't use sgn(x) below because there is no need to distinguish the
     // (x == 0) case.  Also note that there are specialized faster versions
@@ -395,7 +393,7 @@ class MathUtil {
 
   // the sine cardinal function
   static double Sinc(double x) {
-    if (abs(x) < 1E-8) return 1.0;
+    if (fabs(x) < 1E-8) return 1.0;
     return sin(x) / x;
   }
 
