@@ -15,13 +15,15 @@ int const S2::kSwapMask;
 int const S2::kInvertMask;
 double const S2::kMaxDetError = 0.8e-15;  // 14 * (2**-54)
 
-static_assert(S2::kSwapMask == 0x01 && S2::kInvertMask == 0x02,
-              "masks_changed");
+COMPILE_ASSERT(S2::kSwapMask == 0x01 && S2::kInvertMask == 0x02,
+               masks_changed);
 
 static const uint32 MIX32 = 0x12b9b0a1UL;
 
 namespace std {
 
+
+
 // The hash function due to Bob Jenkins (see
 // http://burtleburtle.net/bob/hash/index.html).
 static inline void mix(uint32& a, uint32& b, uint32& c) {     // 32bit version
