@@ -82,7 +82,7 @@ void S2Loop::Init(vector<S2Point> const& vertices) {
     vertices_ = NULL;
   } else {
     vertices_ = new S2Point[num_vertices_];
-    memcpy(vertices_, &vertices[0], num_vertices_ * sizeof(vertices_[0]));
+    memcpy(static_cast<void*>(vertices_), &vertices[0], num_vertices_ * sizeof(vertices_[0]));
   }
   owns_vertices_ = true;
   bound_ = S2LatLngRect::Full();
@@ -244,7 +244,7 @@ S2Loop::S2Loop(S2Loop const* src)
     depth_(src->depth_),
     index_(this),
     num_find_vertex_calls_(0) {
-  memcpy(vertices_, src->vertices_, num_vertices_ * sizeof(vertices_[0]));
+  memcpy(static_cast<void*>(vertices_), src->vertices_, num_vertices_ * sizeof(vertices_[0]));
 }
 
 S2Loop* S2Loop::Clone() const {
