@@ -13,6 +13,7 @@ using std::reverse;
 #include <functional>
 using std::less;
 
+
 #include <unordered_set>
 using std::unordered_set;
 
@@ -114,9 +115,8 @@ S2RegionCoverer::Candidate* S2RegionCoverer::NewCandidate(S2Cell const& cell) {
   if (!is_terminal) {
     size += sizeof(Candidate*) << max_children_shift();
   }
-  void* candidateStorage = malloc(size);
-  memset(candidateStorage, 0, size);
-  Candidate* candidate = new(candidateStorage) Candidate;
+  Candidate* candidate = static_cast<Candidate*>(malloc(size));
+  memset(static_cast<void*>(candidate), 0, size);
   candidate->cell = cell;
   candidate->is_terminal = is_terminal;
   ++candidates_created_counter_;
