@@ -4,9 +4,6 @@
 using std::numeric_limits;
 #include <stdint.h>
 
-#include <iterator>
-using std::back_insert_iterator;
-
 
 #include "base/commandlineflags.h"
 #include "base/integral_types.h"
@@ -117,24 +114,25 @@ HASH_TO((intptr_t c),  static_cast<uint32>(Hash64NumWithSeed(c, MIX64) >> 32))
 #undef HASH_TO        // clean up the macro space
 
 
+// HASH_NAMESPACE_DECLARATION_START
 namespace std {
 
-#if defined(__GNUC__)
-// Use our nice hash function for strings
-//template<class _CharT, class _Traits, class _Alloc>
-//struct hash<basic_string<_CharT, _Traits, _Alloc> > {
-//  size_t operator()(const basic_string<_CharT, _Traits, _Alloc>& k) const {
-//    return HashTo32(k.data(), static_cast<uint32>(k.length()));
-//  }
-//};
-
-// they don't define a hash for const string at all
-template<> struct hash<const string> {
-  size_t operator()(const string& k) const {
-    return HashTo32(k.data(), static_cast<uint32>(k.length()));
-  }
-};
-#endif  // __GNUC__
+// #if defined(__GNUC__)
+// // Use our nice hash function for strings
+// template<class _CharT, class _Traits, class _Alloc>
+// struct hash<basic_string<_CharT, _Traits, _Alloc> > {
+//   size_t operator()(const basic_string<_CharT, _Traits, _Alloc>& k) const {
+//     return HashTo32(k.data(), static_cast<uint32>(k.length()));
+//   }
+// };
+// 
+// // they don't define a hash for const string at all
+// template<> struct hash<const string> {
+//   size_t operator()(const string& k) const {
+//     return HashTo32(k.data(), static_cast<uint32>(k.length()));
+//   }
+// };
+// #endif  // __GNUC__
 
 // MSVC's STL requires an ever-so slightly different decl
 #if defined STL_MSVC
@@ -184,7 +182,7 @@ struct simple_insert_iterator {
   simple_insert_iterator<T>& operator++(int) { return *this; }
 };
 
-// Used to populate a unordered_map out of pairs of consecutive strings in
+// Used to populate a hash_map out of pairs of consecutive strings in
 // SplitStringToIterator{Using|AllowEmpty}().
 template <typename T>
 struct simple_hash_map_iterator {
